@@ -6,28 +6,26 @@ use TestML::Base -base;
 use TestML::Parser::Grammar;
 use TestML::Document;
 
+our $parser;
+
 sub parse {
-    my $parser = TestML::Parser::Grammar->new(
-        rule => 'document',
-        receiver => TestML::Parser::Actions->new,
+    $parser = TestML::Parser::Grammar->new(
+        receiver => TestML::Parser::Receiver->new,
     );
-    $parser->parse($_[1])
+    $parser->parse($_[1], 'document')
         or die "Parse TestML failed";
     return $parser->receiver->document;
 }
 
 sub parse_data {
-    my $parser = TestML::Parser::Grammar->new(
-        rule => 'data_section',
-        receiver => TestML::Parser::Actions->new,
-    );
-    $parser->parse($_[1])
+    $parser->receiver(TestML::Parser::Receiver->new);
+    $parser->parse($_[1], 'data_section')
         or die "Parse TestML data failed";
     return $parser->receiver->document->data->blocks;
 }
 
 #-----------------------------------------------------------------------------
-package TestML::Parser::Actions;
+package TestML::Parser::Receiver;
 use TestML::Base -base;
 
 use TestML::Document;
@@ -72,7 +70,7 @@ sub got_unquoted_string {
 sub got_meta_section {
     my $self = shift;
 
-    my $grammar = TestML::Parser::Grammar->grammar;
+    my $grammar = $parser->grammar;
 
     my $block_marker = $self->document->meta->data->{BlockMarker};
     $block_marker =~ s/([\$\%\^\*\+\?\|])/\\$1/g;
@@ -168,20 +166,17 @@ sub got_string_call {
 }
 
 sub try_assertion_call {
-#     print "try_assertion_call\n";
     my $self = shift;
     $self->statement->assertion(TestML::Assertion->new);
     push @{$self->expression_stack}, $self->statement->assertion->expression;
 }
 
 sub got_assertion_call {
-#     print "got_assertion_call\n";
     my $self = shift;
     pop @{$self->expression_stack};
 }
 
 sub not_assertion_call {
-#     print "not_assertion_call\n";
     my $self = shift;
     $self->statement->assertion(undef);
     pop @{$self->expression_stack};
@@ -230,13 +225,4 @@ sub got_data_block {
     push @{$self->document->data->blocks}, $self->current_block;
 }
 
-# TODO Refactor errors...
-sub got_NO_META_TESTML_ERROR {
-    die 'No TestML meta directive found';
-}
-
-sub got_SEMICOLON_ERROR {
-    die 'You seem to be missing a semicolon';
-}
-
 1;
